# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2016-2018 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""REST API for Records."""

from flask import current_app
from werkzeug.local import LocalProxy

current_records_rest = LocalProxy(
    lambda: current_app.extensions["invenio-records-rest"]
)
"""Proxy to an instance of ``_RecordRESTState``."""
